@@ -1,5 +1,7 @@
+
 import mysql.connector
 from retry import retry
+import logging
 
 
 class Executor(object):
@@ -10,6 +12,10 @@ class Executor(object):
         self.name = name or ('%s-%s' % (self.__class__.__name__, id(self)))
         self._source = None
         self._output = None
+        if kwargs.get('logger') is not None:
+            self.logger = kwargs.get('logger')
+        else:
+            self.logger = logging.getLogger(__name__)
         self.kwargs = kwargs
 
     def __iter__(self):
@@ -43,12 +49,12 @@ class Executor(object):
 
 
 class MysqlExecutor(Executor):
-    def __init__(self, config: dict):
+    def __init__(self, config: dict, **kwargs):
         """
         向一个mysql表读取或写入数据的基础类。
         :param config: 数据库配置
         """
-        super().__init__()
+        super().__init__(**kwargs)
         self.config = config
         self.db = None
         self.cur = None
@@ -58,7 +64,13 @@ class MysqlExecutor(Executor):
         self.db = mysql.connector.connect(**self.config)
         self.cur = self.db.cursor(dictionary=dictionary)
 
+    def connect(self, dictionary=True):
+        self._connect(dictionary)
+
     @retry(tries=3, delay=1)
     def _disconnect(self):
         self.cur.close()
         self.db.close()
+
+    def disconnect(self):
+        self._disconnect()
