@@ -31,28 +31,30 @@ class CsvWriter(Executor):
 
 
 class MysqlWriter(MysqlExecutor):
-    def __init__(self, config: dict, table_name: str, buffer=100):
+    def __init__(self, config: dict, table_name: str, buffer=100, **kwargs):
         """
         向一个mysql表写入数据。
         :param config: 数据库配置
         :param table_name: 表名称
         :param buffer: 多少条数据commit一次。
         """
-        super().__init__(config)
+        super().__init__(config, **kwargs)
         self.table_name = table_name
         self.buffer = buffer
 
     def _output_many(self, items: list):
-        # TODO 检查不同行的数据key的数量是否一致，不一致应该给出提醒。logging.warning.
         assert isinstance(items, list) and len(items) > 0, '输入只能是list,且长度大于0。'
         assert isinstance(items[0], dict), '元素只能是字典，且字典與数据库列表对应。'
-        field_names = ', '.join(items[0].keys())
-        field_values = ')s, %('.join(items[0].keys())
-        sql = 'insert into {} ({}) values (%({})s)'.format(self.table_name, field_names, field_values)
+        item_lengs = set([len(item.keys()) for item in items])
+        if len(item_lengs) > 1:
+            self.logger.warning('注意，输入的字典长度不一致。')
         for item in items:
+            field_names = ', '.join(item.keys())
+            field_values = ')s, %('.join(item.keys())
+            sql = 'insert into {} ({}) values (%({})s)'.format(self.table_name, field_names, field_values)
             self.cur.execute(sql, item)
         self.db.commit()
-        logging.debug('sql commit')
+        self.logger.debug('sql commit')
 
     def output(self):
         if self._source is None:
@@ -75,9 +77,13 @@ class MysqlWriter(MysqlExecutor):
         self._output_many(rows)
         self._disconnect()
 
+    def output_many(self, rows: List[dict]):
+        assert self.db is not None, '请先初始化数据库链接。'
+        self._output_many(rows)
+
 
 class MysqlUpdateWriter(MysqlExecutor):
-    def __init__(self, config: dict, table_name: str, primary_keys: list, buffer=100, write_fail=False):
+    def __init__(self, config: dict, table_name: str, primary_keys: list, buffer=100, write_fail=False, **kwargs):
         """
         更新数据库字段。
         :param config: 数据库配置文件
@@ -86,7 +92,7 @@ class MysqlUpdateWriter(MysqlExecutor):
         :param buffer: 缓存多少才commit
         :param write_fail: 更新失败的是否写到数据库里。
         """
-        super().__init__(config)
+        super().__init__(config, **kwargs)
         self.table_name = table_name
         self.buffer = buffer
         self.primary_keys = primary_keys
@@ -113,7 +119,7 @@ class MysqlUpdateWriter(MysqlExecutor):
         for item in items:
             results = self.cur.execute(sql, item, multi=True)
             result = next(results)
-            logging.debug("Number of rows affected by statement '{}': {}".format(result.statement, result.rowcount))
+            self.logger.debug("Number of rows affected by statement '{}': {}".format(result.statement, result.rowcount))
             if result.rowcount == 0:
                 miss_update.append(item)
         self.db.commit()
@@ -137,6 +143,47 @@ class MysqlUpdateWriter(MysqlExecutor):
         self._disconnect()
 
 
+class MysqlDel(MysqlWriter):
+    def __init__(self, config: dict, table_name: str, key_field: list, buffer=100, **kwargs):
+        super(MysqlDel, self).__init__(config, table_name, buffer, **kwargs)
+        self.key_field = set(key_field)
+
+    def _output_many(self, items: List[dict]):
+        assert isinstance(items, list) and len(items) > 0, '输入只能是list,且长度大于0。'
+        assert isinstance(items[0], dict), '元素只能是字典，且字典與数据库列表对应。'
+        item_lengs = set([len(item.keys()) for item in items])
+        if len(item_lengs) > 1:
+            self.logger.warning('注意，输入的字典长度不一致。')
+        for item in items:
+            element = ['{}=%({})s'.format(item_key, item_key) for item_key in item.keys()]
+            field_names = ' and '.join(element)
+            sql = 'delete from {} where {}'.format(self.table_name, field_names)
+            results = self.cur.execute(sql, item, multi=True)
+            result = next(results)
+            self.logger.debug("Number of rows affected by statement '{}': {}".format(result.statement, result.rowcount))
+        self.db.commit()
+        self.logger.debug('sql commit')
+
+    def output(self):
+        if self._source is None:
+            raise IOError('未指定来源')
+        self._connect()
+
+        tmp_items = []
+        for item in self._source:
+            if len(self.key_field - set(item.keys())) > 0:
+                raise ValueError('删除对象不对应设定的key field，可能删除多条。')
+            item = {key: value for key, value in item.items() if key in self.key_field}
+            tmp_items.append(copy.deepcopy(item))
+            if len(tmp_items) >= self.buffer:
+                self._output_many(tmp_items)
+                tmp_items = []
+        if len(tmp_items) != 0:
+            self._output_many(tmp_items)
+
+        self._disconnect()
+
+
 class ScreenOutput(Executor):
     def __init__(self, end='\n'):
         """在屏幕打印出输出结果。"""
